aboutsummaryrefslogtreecommitdiff
path: root/internal/syscallcompat/sys_darwin.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/syscallcompat/sys_darwin.go')
-rw-r--r--internal/syscallcompat/sys_darwin.go11
1 files changed, 8 insertions, 3 deletions
diff --git a/internal/syscallcompat/sys_darwin.go b/internal/syscallcompat/sys_darwin.go
index 74681db..993c229 100644
--- a/internal/syscallcompat/sys_darwin.go
+++ b/internal/syscallcompat/sys_darwin.go
@@ -9,9 +9,14 @@ import (
"github.com/hanwen/go-fuse/fuse"
)
-// O_DIRECT means oncached I/O on Linux. No direct equivalent on MacOS and defined
-// to zero there.
-const O_DIRECT = 0
+const (
+ // O_DIRECT means oncached I/O on Linux. No direct equivalent on MacOS and defined
+ // to zero there.
+ O_DIRECT = 0
+
+ // O_PATH is only defined on Linux
+ O_PATH = 0
+)
// Sorry, fallocate is not available on OSX at all and
// fcntl F_PREALLOCATE is not accessible from Go.